==> haskell-list-t-1.0.5.7-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-9oyi3iwHgtEK0nY14RH97z
key:                  list-t-1.0.5.7-9oyi3iwHgtEK0nY14RH97z
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  b010734193587c34318d0743dec89af2
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-9oyi3iwHgtEK0nY14RH97z
depends:
    base-4.17.2.1 foldl-1.4.18-3PF7ymacwaYEGfM0lGSBKh
    logict-0.8.2.0-3m4Vek1c8MCEJ2CeIZ7zhK
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    monad-control-1.0.3.1-7n08D4f3cZlHQLReW5zr2o mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-EUpMRDZS1pg4wf9RVhNjt2

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-list-t-1.0.5.7-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-2rX6aYqtsKU7VXETQfIFgc
key:                  list-t-1.0.5.7-2rX6aYqtsKU7VXETQfIFgc
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  c0ba36a0a8a5bab846142fd46951fb48
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-2rX6aYqtsKU7VXETQfIFgc
depends:
    base-4.17.2.1 foldl-1.4.18-CB1msuz6DE378GLjjzZeLN
    logict-0.8.2.0-4jmovAXKz6GKA9nUpHwnAM
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    monad-control-1.0.3.1-LvD2QGBgFgqFpndGGLy7SM mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-HugzaWq8ZFe99E7DUGbdeP

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
